.. tekuila documentation master file, created by
   sphinx-quickstart on Fri Jan 16 15:06:39 2015.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to tekuila's documentation!
===================================

This is a simple Python library for parsing your ISPs download limits API.

Contents:

.. toctree::
   :maxdepth: 2

   tekuila
   isps
   contributing

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

